#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    StringTable,
    DiscoveryResult,
    CheckResult,
    Service,
    get_value_store,
)

from cmk.plugins.lib.cpu_util import check_cpu_util

from cmk_addons.plugins.emcunity.lib.utils import *

import time


def parse_emcunity_cpu(string_table: StringTable) -> dict[str, dict[str, str]]:
    parsed= {}
    for line in string_table:
        time, id, utilization = line
        parsed[id] = {
            "utilization": utilization,
            "time": time,
        }
    return parsed

agent_section_emcunity_cpu = AgentSection(
    name="emcunity_cpu",
    parse_function=parse_emcunity_cpu,
)

def discover_emcunity_cpu(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    for cpu in section:
        yield Service(
            item = cpu,
        )

def check_emcunity_cpu(item: str, params: dict, section: dict[str, dict[str, str]]) -> CheckResult:
    for cpu_id, cpu in section.items():
        if cpu_id == item:
            yield from check_cpu_util(
                util=float(cpu.get("utilization")),
                params=params,
                value_store=get_value_store,
                this_time=time.time(),
            )

check_plugin_emcunity_cpu = CheckPlugin(
    name="emcunity_cpu",
    service_name="CPU Utilization %s",
    discovery_function=discover_emcunity_cpu,
    check_function=check_emcunity_cpu,
    check_ruleset_name="cpu_utilization_multiitem",
    check_default_parameters={"levels": (90.0, 95.0)},
)