#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    CheckResult,
    DiscoveryResult,
    State,
    Service,
    Result,
)

from cmk_addons.plugins.emcunity.lib.utils import *


agent_section_emcunity_fc = AgentSection(
    name="emcunity_fc",
    parse_function=parse_emcunity_generic,
)


def discover_emcunity_fc(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    for _id, element in section.items():
        name_raw = element.get("Name").split()
        name = f"{name_raw[1]} {name_raw[-1]}"
        yield Service(
            item = name,
        )

def check_emcunity_fc(item: str, section: dict[str, dict[str, str]]) -> CheckResult:
    for _id, fc in section.items():
        name_raw = fc.get("Name").split()
        name = f"{name_raw[1]} {name_raw[-1]}"
        if name == item:
            yield from check_health(fc.get("Health state"), fc.get('Health details'))
            speed = fc.get('Speed')
            if speed == "":
                speed = "None"
            yield Result(
                state=State.OK,
                summary=f"Speed: {speed}",
            )

check_plugin_emcunity_fc = CheckPlugin(
    name="emcunity_fc",
    service_name="FC Port %s",
    discovery_function=discover_emcunity_fc,
    check_function=check_emcunity_fc,
)