#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    CheckResult,
    Service,
    State,
    DiscoveryResult,
    Result,
)

from cmk_addons.plugins.emcunity.lib.utils import *


agent_section_emcunity_general = AgentSection(
    name="emcunity_general",
    parse_function=parse_emcunity_generic,
)


def discover_emcunity_general(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    for id, _element in section.items():
        yield Service(
            item = id,
        )

def check_emcunity_general(item: str, section: dict[str, dict[str, str]]) -> CheckResult:
    for id, system in section.items():
        if id == item:
            yield from check_health(system.get("Health state"), system.get('Health details')) 
            yield Result(
                state=State.OK,
                summary=f"Model: {system.get("Model")}",
            )

check_plugin_emcunity_general = CheckPlugin(
    name="emcunity_general",
    service_name="System %s",
    discovery_function=discover_emcunity_general,
    check_function=check_emcunity_general,
)