#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    CheckResult,
    Result,
    State,
)

from cmk_addons.plugins.emcunity.lib.utils import *


agent_section_emcunity_hostcons = AgentSection(
    name="emcunity_hostcons",
    parse_function=parse_emcunity_generic,
)


def check_emcunity_hostcons(section: dict[str, dict[str, str]]) -> CheckResult:
    for _id, hostcon in section.items():
        yield from check_health_multi(hostcon.get("Name"), hostcon.get("Health state"), hostcon.get('Health details'))
        yield Result(
            state=State.OK,
            summary=f"{hostcon.get("Name")}: OS: {hostcon.get("OS type")}, IP: {hostcon.get("Address")}",
        )

check_plugin_emcunity_hostcons = CheckPlugin(
    name="emcunity_hostcons",
    service_name="Host Connections",
    discovery_function=discover_emcunity_generic_single,
    check_function=check_emcunity_hostcons,
)