#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    StringTable,
    DiscoveryResult,
    CheckResult,
    Service,
    get_value_store,
)

from cmk.plugins.lib.temperature import *


def parse_emcunity_temp(string_table: StringTable) -> dict[str, dict[str, str]]:
    parsed= {}
    for line in string_table:
        time, id, temp = line
        parsed[id] = {
            "temperature": temp,
            "time": time,
        }
    return parsed

agent_section_emcunity_temp = AgentSection(
    name="emcunity_temp",
    parse_function=parse_emcunity_temp,
)


def discover_emcunity_temp(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    for temp in section:
        yield Service(
            item = temp,
        )

def check_emcunity_temp(item: str, params: dict, section: dict[str, dict[str, str]]) -> CheckResult:
    for temp_id, temp in section.items():
        if temp_id == item:
            yield from check_temperature(
                dev_unit="c",
                params=params,
                reading=float(temp.get("temperature")),
                unique_name=item,
                value_store=get_value_store,
            )

check_plugin_emcunity_temp = CheckPlugin(
    name="emcunity_temp",
    service_name="Temperature %s",
    discovery_function=discover_emcunity_temp,
    check_function=check_emcunity_temp,
    check_ruleset_name="temperature",
    check_default_parameters={},
)