#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.graphing.v1 import Title

from cmk.graphing.v1.metrics import (
    Metric,
    Unit,
    DecimalNotation,
    Color,
)

from cmk.graphing.v1.graphs import Graph

from cmk.gui.plugins.metrics.translation import df_translation, check_metrics

check_metrics["check_mk-emcunity_fs"] = df_translation
check_metrics["check_mk-emcunity_lun"] = df_translation
check_metrics["check_mk-emcunity_pool"] = df_translation
check_metrics["check_mk-emcunity_vmfs"] = df_translation

metric_emcunity_eol_in_days = Metric(
    name="emcunity_eol_in_days",
    title=Title("EOL in days"),
    unit=Unit(DecimalNotation("Days")),
    color=Color.BLUE,
)

metric_emcunity_dpe_power = Metric(
    name="emcunity_dpe_power",
    title=Title("Power"),
    unit=Unit(DecimalNotation("Watts")),
    color=Color.CYAN,
)


graph_emcunity_eol_in_days = Graph(
    name="emc_unity_eol_in_days",
    title=Title("EOL in days"),
    compound_lines=[
        "emcunity_eol_in_days",
    ],
)

graph_emcunity_dpe_power = Graph(
    name="emcunity_dpe_power",
    title=Title("Power"),
    compound_lines=[
        "emcunity_dpe_power",
    ],
)