#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

import re # type: ignore
from cmk.agent_based.v2 import (
    State,
    CheckResult,
    Result,
    StringTable,
    DiscoveryResult,
    Service,
)
from cmk.plugins.lib.df import (
    MAGIC_FACTOR_DEFAULT_PARAMS,
    SHOW_LEVELS_DEFAULT,
    INODES_DEFAULT_PARAMS,
    TREND_DEFAULT_PARAMS,
)

EMCUNITY_DEFAULT_PARAMS = {
    "levels": (101.0, 101.0),
    **MAGIC_FACTOR_DEFAULT_PARAMS,
    **SHOW_LEVELS_DEFAULT,
    **INODES_DEFAULT_PARAMS,
    "show_reserved": False,
    **TREND_DEFAULT_PARAMS,
}

EMC_STATE = {
    "0": State.UNKNOWN,
    "5": State.OK,
    "7": State.WARN,
    "10": State.WARN,
    "15": State.WARN,
    "20": State.CRIT,
    "25": State.CRIT,
    "30": State.CRIT,
}

def _parse_emcunity_health_state(health_state: str) -> State:
    state = re.search(r'\d+', health_state)
    code = EMC_STATE.get(state.group(0), State.UNKNOWN)
    return code

def _parse_emcunity_health_details(health_details: str) -> str:
    if re.match(r".*no action is required*", health_details, re.IGNORECASE):
        return "Health: OK"
    elif re.match(r".*is operating normally.*", health_details, re.IGNORECASE):
        return "Health: OK"
    elif re.match(r".*slot is empty.*", health_details, re.IGNORECASE):
        return "Health: OK, Slot is empty"
    else:
        return "Health: Not OK"



def parse_emcunity_generic(string_table: StringTable) -> dict[str, dict[str, str]]:
    parsed = {}
    id = ""
    for line in string_table:
        try:
            k, v = line
        except ValueError:
            return None
        k = k.strip()
        v = v.strip()
        if re.match(r"^\d+:.*\w+", k):
            id = v
            parsed[id] = {}
        elif re.match(r"Health details", k):
            parsed[id][k] = v.strip('\"')
        else:
            parsed[id][k] = v
    return parsed


def discover_emcunity_generic(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    for _id, element in section.items():
        yield Service(
            item = element.get("Name"),
        )

def discover_emcunity_generic_single(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    yield Service()


def check_health(health_state: str, health_details: str) -> CheckResult:
    yield Result(
        state=_parse_emcunity_health_state(health_state),
        summary=_parse_emcunity_health_details(health_details),
        details=f"{health_details}, {health_state}",
    )

def check_health_multi(name: str, health_state: str, health_details: str) -> CheckResult:
    yield Result(
        state=_parse_emcunity_health_state(health_state),
        summary=f"{name}: {_parse_emcunity_health_details(health_details)}",
        details=f"{name}: {health_details}, {health_state}",
    )