#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.rulesets.v1 import (
    Title,
)

from cmk.rulesets.v1.form_specs import (
    Dictionary,
    DictElement,
    DefaultValue,
    SimpleLevels,
    LevelDirection,
    Integer,
)

from cmk.rulesets.v1.rule_specs import (
    CheckParameters,
    Topic,
    HostAndItemCondition,
)


def _form_emcunity_disk() -> Dictionary:
    return Dictionary(
        title=Title("EMC Unity Disk"),
        elements={
            "eol": DictElement(
                parameter_form=SimpleLevels(
                    title=Title("Time to EOL"),
                    level_direction=LevelDirection.LOWER,
                    form_spec_template=Integer(),
                    prefill_fixed_levels=DefaultValue(value=(60, 30)),
                )
            )
        }
    )

rule_spec_emcunity_disk = CheckParameters(
    name="emcunity_disk",
    title=Title("EMC Unity Disk"),
    topic=Topic.STORAGE,
    condition=HostAndItemCondition(
        item_title=Title("Disk"),
    ),
    parameter_form=_form_emcunity_disk,
)