#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

from cmk.server_side_calls.v1 import (
    HostConfig,
    Secret,
    SpecialAgentCommand,
    SpecialAgentConfig,
)
from pydantic import BaseModel
from collections.abc import Iterator # type: ignore


class EMCUnityParams(BaseModel):
    username: str
    password: Secret

def generate_emcunity_commands(params: EMCUnityParams, host_config: HostConfig) -> Iterator[SpecialAgentCommand]:
    yield SpecialAgentCommand(
        command_arguments=[
            "-u",
            params.username,
            "-p",
            params.password.unsafe(),
            host_config.primary_ip_config.address,
        ],
    )

special_agent_emcunity=SpecialAgentConfig(
    name="emcunity",
    parameter_parser=EMCUnityParams.model_validate,
    commands_function=generate_emcunity_commands,
)